==> h5p-7.x-1.28.tar.gz: h5p/modules/h5peditor/h5peditor/language/fr.js <==
H5PEditor.language.core = {
  missingTranslation: '[Traduction manquante :key]',
  loading: 'Chargement en cours, merci de patienter...',
  selectLibrary: 'Sélectionnez une activité pour votre exercice.',
  unknownFieldPath: 'Impossible de trouver ":path".',
  notImageField: '":path" n\'est pas une image.',
  notImageOrDimensionsField: '":path" n est pas une image ou aux bonnes dimensions.',
  requiredProperty: 'Le champ :property est obligatoire et ne peut être vide.',
  onlyNumbers: 'Le champ :property ne peut contenir que des nombres.',
  exceedsMax: 'La valeur du champ :property est supérieure au maximum de :max.',
  listExceedsMax: 'The list exceeds the maximum of :max items.',
  belowMin: 'La valeur du champ :property est inférieure au minimum de :min.',
  listBelowMin: 'The list needs at least :min items for the content to function properly.',
  outOfStep: 'La :property ne peut être effectuée que par étape  :step.',
  add: 'Ajouter',
  addFile: 'Ajouter un fichier',
  removeFile: 'Supprimer un fichier',
  confirmRemoval: 'Voulez-vous vraiment supprimer :type&nbsp;?',
  removeImage: 'Supprimer l\'image',
  confirmImageRemoval: 'Votre image va être supprimée. Êtes- vous sûr de vouloir continuer&nbsp;?',
  changeFile: 'Changer le fichier',
  changeLibrary: 'Changer le type de contenu',
  semanticsError: 'Erreur de langue: :error',
  missingProperty: 'Le champ :index ne comporte pas la mention :property.',
  expandCollapse: 'Dérouler/Enrouler',
  addEntity: 'Ajouter :entity',
  tooLong: 'Ce mot est trop long, il ne peut comporter que :max lettres ou moins.',
  invalidFormat: 'Ce champ contient un format ou un caractère invalide.',
  confirmChangeLibrary: 'Etes-vous certain de vouloir passer à une autre activité&nbsp;?',
  commonFields: 'Options et textes',
  commonFieldsDescription: 'Vous pouvez ici éditer les options et les textes.',
  uploading: 'Chargement en cours...',
  noFollow: 'Impossible de suivre le champ ":path".',
  editCopyright: 'Editer le copyright',
  close: 'Fermer',
  tutorial: 'Tutoriel',
  example: 'Example',
  editMode: 'Mode de rédaction',
  listLabel: 'Liste',
  uploadError: 'Erreur pendant l\'envoi du fichier',
  fileToLarge: 'Le fichier que vous envoyez est trop lourd.',
  unknownFileUploadError: 'Unknown file upload error',
  noSemantics: 'Erreur, impossible de charger ce type de contenu.',
  editImage: 'Editer l\'image',
  saveLabel: 'Enregistrer',
  cancelLabel: 'Annuler',
  resetToOriginalLabel: 'Réinitialiser',
  loadingImageEditor: 'Editeur d\'image en cours de chargement, patientez...',
  selectFiletoUpload: 'Choisissez le fichier à charger',
  or: 'ou',
  enterAudioUrl: 'Entrez l\'URL de la source audio',
  enterVideoUrl: 'Entrez l\'URL de la source vidéo ou du lien YouTube',
  enterAudioTitle: 'Paste link or other audio source URL',
  enterVideoTitle: 'Paste YouTube link or other video source URL',
  uploadAudioTitle: 'Upload audio file',
  uploadVideoTitle: 'Upload video file',
  addVideoDescription: 'H5P supporte toutes les sources vidéo externes aux fomats mp4, webm ou ogv, tels que Vimeo Pro, ainsi que les liens YouTube.',
  insert: 'Insérer',
  cancel: 'Annuler',
  height: 'hauteur',
  width: 'largeur',
  textField: 'texte',
  numberField: 'numérique',
  orderItemUp: 'Order item up',
  orderItemDown: 'Order item down',
  removeItem: 'Remove item',
  hubPanelLabel: 'Select content type',
  importantInstructions: 'Important instructions',
  hideImportantInstructions: 'Hide important instructions',
  hide: 'Hide',
  example: 'Example',
  createContentTabLabel: 'Create Content',
  uploadTabLabel: 'Upload',
  uploadPlaceholder: 'No file chosen',
  uploadInstructionsTitle: 'Upload an H5P file.',
  uploadInstructionsContent: 'You may start with examples from <a href="https://h5p.org/content-types-and-applications" target="blank">H5P.org</a>.',
  uploadFileButtonLabel: 'Upload a file',
  uploadFileButtonChangeLabel: 'Change file',
  uploadingThrobber: 'Now uploading...',
  h5pFileWrongExtensionTitle: 'The selected file could not be uploaded',
  h5pFileWrongExtensionContent: 'Only files with the .h5p extension are allowed.',
  h5pFileValidationFailedTitle: 'Could not validate H5P file.',
  h5pFileValidationFailedContent: 'Make sure the uploaded H5P contains valid H5P content. H5P' +
  ' files containing only libraries should be uploaded through the H5P Libraries page.',
  h5pFileUploadServerErrorTitle: 'The H5P file could not be uploaded',
  h5pFileUploadServerErrorContent: 'An unexpected error occured. Check your server error log for' +
  ' more details.',
  contentTypeSectionAll: 'All',
  contentTypeSectionMine: 'My Content Types',
  contentTypeSectionPopular: 'Most Popular',
  contentTypeSectionTitle: 'Browse content types',
  contentTypeSearchFieldPlaceholder: 'Search for Content Types',
  contentTypeInstallButtonLabel: 'Install',
  contentTypeInstallingButtonLabel: 'Installing',
  contentTypeUseButtonLabel: 'Use',
  contentTypeUpdateButtonLabel: 'Update',
  contentTypeUpdatingButtonLabel: 'Updating',
  contentTypeGetButtonLabel: 'Get',
  contentTypeBackButtonLabel: 'Back',
  contentTypeIconAltText: 'Icon',
  contentTypeInstallSuccess: ':contentType successfully installed!',
  contentTypeUpdateSuccess: ':contentType successfully updated!',
  contentTypeInstallError: ':contentType could not be installed. Contact your administrator.',
  contentTypeLicensePanelTitle: 'License',
  contentTypeDemoButtonLabel: 'Content Demo',
  readMore: 'Read more',
  readLess: 'Read less',
  contentTypeOwner: 'By :owner',
  contentTypeUnsupportedApiVersionTitle: 'This content type requires a newer core version',
  contentTypeUnsupportedApiVersionContent: 'Contact your system administrator to provide you with the necessary updates',
  contentTypeUpdateAvailable: 'Update available',
  contentTypeRestricted: 'Restricted content type',
  contentTypeRestrictedDesc: 'The use of this content type has been restricted by an administrator.',
  contentTypeNotInstalled: 'Content type not installed',
  contentTypeNotInstalledDesc: 'You do not have permission to install content types.',
  theContentType: 'the content type',
  currentMenuSelected: 'current selection',
  errorCommunicatingHubTitle: 'Not able to communicate with hub.',
  errorCommunicatingHubContent: 'An error occured. Please try again.',
  warningNoContentTypesInstalled: "You don't have any content types installed.",
  warningChangeBrowsingToSeeResults: 'Click <em>All</em> to get the list of all the content types you can install.',
  warningUpdateAvailableTitle: 'A new version of :contentType is available.',
  warningUpdateAvailableBody: 'Update to the latest version for an improved experience.',
  licenseDescription: 'Some of the features of this license are indicated below. Click the info icon above to read the original license text.',
  licenseModalTitle: 'License Details',
  licenseModalSubtitle: 'Select a license to view information about proper usage',
  licenseUnspecified: 'Unspecified',
  licenseCanUseCommercially: 'Can use commercially',
  licenseCanModify: 'Can modify',
  licenseCanDistribute: 'Can distribute',
  licenseCanSublicense: 'Can sublicense',
  licenseCanHoldLiable: 'Can hold liable',
  licenseCannotHoldLiable: 'Cannot hold liable',
  licenseMustIncludeCopyright: 'Must include copyright',
  licenseMustIncludeLicense: 'Must include license',
  licenseFetchDetailsFailed: 'Failed fetching license details',
  imageLightboxTitle: 'Images',
  imageLightBoxProgress: ':num of :total',
  nextImage: 'Next image',
  previousImage: 'Previous image',
  screenshots: 'Screenshots',
  reloadButtonLabel: 'Reload'
};

==> h5p-7.x-1.30.tar.gz: h5p/modules/h5peditor/h5peditor/language/fr.js <==
H5PEditor.language.core = {
  missingTranslation: '[Traduction manquante :key]',
  loading: 'Chargement en cours, merci de patienter...',
  selectLibrary: 'Sélectionnez une activité pour votre exercice.',
  unknownFieldPath: 'Impossible de trouver ":path".',
  notImageField: '":path" n\'est pas une image.',
  notImageOrDimensionsField: '":path" n est pas une image ou aux bonnes dimensions.',
  requiredProperty: 'Le champ :property est obligatoire et ne peut être vide.',
  onlyNumbers: 'Le champ :property ne peut contenir que des nombres.',
  exceedsMax: 'La valeur du champ :property est supérieure au maximum de :max.',
  listExceedsMax: 'The list exceeds the maximum of :max items.',
  belowMin: 'La valeur du champ :property est inférieure au minimum de :min.',
  listBelowMin: 'The list needs at least :min items for the content to function properly.',
  outOfStep: 'La :property ne peut être effectuée que par étape  :step.',
  add: 'Ajouter',
  addFile: 'Ajouter un fichier',
  removeFile: 'Supprimer un fichier',
  confirmRemoval: 'Voulez-vous vraiment supprimer :type&nbsp;?',
  removeImage: 'Supprimer l\'image',
  confirmImageRemoval: 'Votre image va être supprimée. Êtes- vous sûr de vouloir continuer&nbsp;?',
  changeFile: 'Changer le fichier',
  changeLibrary: 'Changer le type de contenu',
  semanticsError: 'Erreur de langue: :error',
  missingProperty: 'Le champ :index ne comporte pas la mention :property.',
  expandCollapse: 'Dérouler/Enrouler',
  addEntity: 'Ajouter :entity',
  tooLong: 'Ce mot est trop long, il ne peut comporter que :max lettres ou moins.',
  invalidFormat: 'Ce champ contient un format ou un caractère invalide.',
  confirmChangeLibrary: 'Etes-vous certain de vouloir passer à une autre activité&nbsp;?',
  commonFields: 'Options et textes',
  commonFieldsDescription: 'Vous pouvez ici éditer les options et les textes.',
  uploading: 'Chargement en cours...',
  noFollow: 'Impossible de suivre le champ ":path".',
  editCopyright: 'Editer le copyright',
  close: 'Fermer',
  tutorial: 'Tutoriel',
  example: 'Example',
  editMode: 'Mode de rédaction',
  listLabel: 'Liste',
  uploadError: 'Erreur pendant l\'envoi du fichier',
  fileToLarge: 'Le fichier que vous envoyez est trop lourd.',
  unknownFileUploadError: 'Unknown file upload error',
  noSemantics: 'Erreur, impossible de charger ce type de contenu.',
  editImage: 'Editer l\'image',
  saveLabel: 'Enregistrer',
  cancelLabel: 'Annuler',
  resetToOriginalLabel: 'Réinitialiser',
  loadingImageEditor: 'Editeur d\'image en cours de chargement, patientez...',
  selectFiletoUpload: 'Choisissez le fichier à charger',
  or: 'ou',
  enterAudioUrl: 'Entrez l\'URL de la source audio',
  enterVideoUrl: 'Entrez l\'URL de la source vidéo ou du lien YouTube',
  enterAudioTitle: 'Paste link or other audio source URL',
  enterVideoTitle: 'Paste YouTube link or other video source URL',
  uploadAudioTitle: 'Upload audio file',
  uploadVideoTitle: 'Upload video file',
  addVideoDescription: 'H5P supporte toutes les sources vidéo externes aux fomats mp4, webm ou ogv, tels que Vimeo Pro, ainsi que les liens YouTube.',
  insert: 'Insérer',
  cancel: 'Annuler',
  height: 'hauteur',
  width: 'largeur',
  textField: 'texte',
  numberField: 'numérique',
  orderItemUp: 'Order item up',
  orderItemDown: 'Order item down',
  removeItem: 'Remove item',
  hubPanelLabel: 'Select content type',
  importantInstructions: 'Important instructions',
  hideImportantInstructions: 'Hide important instructions',
  hide: 'Hide',
  example: 'Example',
  createContentTabLabel: 'Create Content',
  uploadTabLabel: 'Upload',
  uploadPlaceholder: 'No file chosen',
  uploadInstructionsTitle: 'Upload an H5P file.',
  uploadInstructionsContent: 'You may start with examples from <a href="https://h5p.org/content-types-and-applications" target="blank">H5P.org</a>.',
  uploadFileButtonLabel: 'Upload a file',
  uploadFileButtonChangeLabel: 'Change file',
  uploadingThrobber: 'Now uploading...',
  h5pFileWrongExtensionTitle: 'The selected file could not be uploaded',
  h5pFileWrongExtensionContent: 'Only files with the .h5p extension are allowed.',
  h5pFileValidationFailedTitle: 'Could not validate H5P file.',
  h5pFileValidationFailedContent: 'Make sure the uploaded H5P contains valid H5P content. H5P' +
  ' files containing only libraries should be uploaded through the H5P Libraries page.',
  h5pFileUploadServerErrorTitle: 'The H5P file could not be uploaded',
  h5pFileUploadServerErrorContent: 'An unexpected error occured. Check your server error log for' +
  ' more details.',
  contentTypeSectionAll: 'All',
  contentTypeSectionMine: 'My Content Types',
  contentTypeSectionPopular: 'Most Popular',
  contentTypeSectionTitle: 'Browse content types',
  contentTypeSearchFieldPlaceholder: 'Search for Content Types',
  contentTypeInstallButtonLabel: 'Install',
  contentTypeInstallingButtonLabel: 'Installing',
  contentTypeUseButtonLabel: 'Use',
  contentTypeUpdateButtonLabel: 'Update',
  contentTypeUpdatingButtonLabel: 'Updating',
  contentTypeGetButtonLabel: 'Get',
  contentTypeBackButtonLabel: 'Back',
  contentTypeIconAltText: 'Icon',
  contentTypeInstallSuccess: ':contentType successfully installed!',
  contentTypeUpdateSuccess: ':contentType successfully updated!',
  contentTypeInstallError: ':contentType could not be installed. Contact your administrator.',
  contentTypeLicensePanelTitle: 'License',
  contentTypeDemoButtonLabel: 'Content Demo',
  readMore: 'Read more',
  readLess: 'Read less',
  contentTypeOwner: 'By :owner',
  contentTypeUnsupportedApiVersionTitle: 'This content type requires a newer core version',
  contentTypeUnsupportedApiVersionContent: 'Contact your system administrator to provide you with the necessary updates',
  contentTypeUpdateAvailable: 'Update available',
  contentTypeRestricted: 'Restricted content type',
  contentTypeRestrictedDesc: 'The use of this content type has been restricted by an administrator.',
  contentTypeNotInstalled: 'Content type not installed',
  contentTypeNotInstalledDesc: 'You do not have permission to install content types.',
  theContentType: 'the content type',
  currentMenuSelected: 'current selection',
  errorCommunicatingHubTitle: 'Not able to communicate with hub.',
  errorCommunicatingHubContent: 'An error occured. Please try again.',
  warningNoContentTypesInstalled: "You don't have any content types installed.",
  warningChangeBrowsingToSeeResults: 'Click <em>All</em> to get the list of all the content types you can install.',
  warningUpdateAvailableTitle: 'A new version of :contentType is available.',
  warningUpdateAvailableBody: 'Update to the latest version for an improved experience.',
  licenseDescription: 'Some of the features of this license are indicated below. Click the info icon above to read the original license text.',
  licenseModalTitle: 'License Details',
  licenseModalSubtitle: 'Select a license to view information about proper usage',
  licenseUnspecified: 'Unspecified',
  licenseCanUseCommercially: 'Can use commercially',
  licenseCanModify: 'Can modify',
  licenseCanDistribute: 'Can distribute',
  licenseCanSublicense: 'Can sublicense',
  licenseCanHoldLiable: 'Can hold liable',
  licenseCannotHoldLiable: 'Cannot hold liable',
  licenseMustIncludeCopyright: 'Must include copyright',
  licenseMustIncludeLicense: 'Must include license',
  licenseFetchDetailsFailed: 'Failed fetching license details',
  imageLightboxTitle: 'Images',
  imageLightBoxProgress: ':num of :total',
  nextImage: 'Next image',
  previousImage: 'Previous image',
  screenshots: 'Screenshots',
  reloadButtonLabel: 'Reload',
  videoQuality: 'Video quality label',
  videoQualityDescription: 'This label helps the user identify the current quality of the video. E.g. 1080p, 720p, HD or Mobile',
  videoQualityDefaultLabel: 'Quality :index'
};
